###############################################################################
# Author  : Patrick Régnier
# Created : 5/1997
# Last modified: 02/2016 
# This is the default Tcl script file for the astrologic interpretation
# of a horoscope. You can modifie it if you know Tcl langage.
# Commands added to Tcl for astrological purpose are listed in file 
# commands_part1.tcl and commands_part2.tcl 
# Any suggestions and good ideas welcome 
# (see online help for how to contact me).
# For others langages than French, please translate inter.txt to your own
# language. inter.txt must be in text(UTF8 without BOM) mode.
################################################################################

################################################################################
# Conventions
#
# Numbers of signs   are 0 to 11 Aries to Pisces
#
# Numbers of planets in Proastro are 0 to 14 :
# 0  = Sun,     1 = Moon,      2 = Mercury,
# 3  = Venus,   4 = Mars,      5 = Jupiter
# 6  = Saturn   7 = Ascendant, 8 = Mid-heaven,
# 9  = Rahu (Ascendant node of moon), 10 = Kethu (Descendant node of moon)
# 11 = Uranus, 12 = Neptun,   13 = Pluto, 14 = Fortune
#
#####################################################################################
# Dans le fichier inter_fr1.txt, les textes correspondent aux maisons comptées
# selon le sens CONTRAIRE aux signes. 
# Le texte planète en maison 4  correspond au texte planète au MC
# Le texte planète en maison 10 correspond au texte planète au FC
# et ce, même si la maison 4 "signes maisons sens contraire" correspond à la maison 9 "signes maisons même sens"
# ou si la maison 10 "signes maisons sens contraire" correspond à la maison 3 "signes maisons même sens".
# D'où l'inversion ci-dessous, pour que l'erreur soit plus juste ;)
# Pour ceux que ne travaillent que "maisons signes dans le même sens"
# Une solution peut-être de créer un nouveau fichier d'interprétation inter_fr10.txt, copie de inter_fr1.txt, par 
# exemple et permuter les textes planètes en maison 4 et 10 et de faire pointer ce script ou
# une copie sur le fichier inter_fr10.txt avec l'instruction 
# set idfi 10
# il est possible d'ajouter des entrée dans le menu Interprétation/Personnalisé
# en éditant le fichier menu_tcl_tk.ini dans le répertoire privé de Proastro. 
######################################################################################
# In the file inter_us1.txt The text are for houses in the OPPOSITE direction of signs. 
# The text planet in house 4 matches planet in MH
# The text planet in house 10 matches planet in IC, 
# even if the house 4 "signs houses opposite direction" is the 9th "signs houses same direction"
# or if the house 10 "signs houses opposite direction" corresponds to the house 3 "signs houses same direction". 
# Hence the inversion below. One solution may be to create a new interpretation file inter_us10.txt 
# and swap planets texts house 4 to 10 and to point this script or a copy of it to the inter_fr10.txt file with instruction 
# set idfi 10
# It is possible to add entry in the Interpretation/Custom menu by editing the menu_tcl_tk.ini file in the Proastro
# private directory.
#####################################################################################

proc permuteHouseNumber { nhouse option_house } {

if { $option_house=="-shsd" } {
   
  switch $nhouse {

   1  {return 1}
   2  {return 2}
   3  {return 3}
   4  { PutTxt "Inversion txt 4 ~-> 10"
        return 10
       }
   5  {return 5}
   6  {return 6}
   7  {return 7}
   8  {return 8}
   9  {return 9}
   10 { PutTxt "Inversion txt 10 ~-> 4"
        return 4
      }
   11 {return 11}
   12  {return 12}
   default {return $nhouse}
  }
 } else {
  return $nhouse
 }

}

#--- give the number of Astro text paragraph 
#--- for an aspect between two planets 

proc nAspectTxt { a b quality origin } {
if { $quality > 0 } { set dec 0 } else {set dec 1}
if {$a > $b} {
 set i $b
 set j $a } else {
 set i $a
set j $b
}
  	         
 
 set k [expr $origin + 28*$i - $i*($i-1) + 2*($j -$i -1)  + $dec]
 return $k
}


# get de 2 first letters of a planet, in US language
# used for stars interpretation 
proc getPlanetUSPrefix { a } {

 switch $a {
 
 0  {return "SU"}
 1  {return "MO"}
 2  {return "ME"}
 3  {return "VE"}
 4  {return "MA"}
 5  {return "JU"}
 6  {return "SA"}
 7  {return "AS"}
 8  {return "MH"}
 9  {return "RA"}
 10 {return "KE"}
 11 {return "UR"}
 12 {return "NE"}
 13 {return "PL"}
 14 {return "FO"}
  
 } 

}


#--- Get quality of planets

proc FindQualityOfPanets {} {
 
 # 0 = neutral, 1 = Good, -1 = Bad
 # QualityOfPlanet is a global array
 
 global QualityOfPlanet
 set ncrosschecking 7
 
 for {set i 0} { $i < 15 } {incr i} {
   
  set QualityOfPlanet($i) [HQualityOfPlanet $i $ncrosschecking]   
 }

 # force quality of fortune to benefic
 set QualityOfPlanet(14) 1

}

################################################################################
# Initializations
################################################################################

# Set debug on or off
# Warning: Must be the first instruction!
# if Debug is on, index file for inter.txt will be overwritten
# each time this script is being executed, witch will slow down performance

SetPRDebug -off

# Rebuild index 
# this allow you to change interpretation files and check this script output without need of restarting Proastro
# usefull if you are testing changes in interpretation files
# RebuildInterpTxtIndex


# Open the horoscope for interpretation
if {![SetCurrentHoroscope]} {
 PutTxt "interpretation aborted"
return
}

# Get Astro Type

if { [GetAstroType]!=0} {
 # Movable Astrology
 set options_signs   "-mov"
} else {
# Fix Astrology
 set options_signs   "-fix"
}

# house direction
if { [isSHSD]!= 0} {
 # house and sign same direction
 set options_houses  "-shsd"
} else {
# house and sign opposite direction
 set options_houses  "-shod"
}

# cusp of house in center of house 

if { [isHouseCuspCenter]!= 0} {
 set options_houses_center  "-center"
} else {
set options_houses_center  ""
} 


set nplanet_AS 7
set nplanet_MH 8

# id of interpretation file
set idfi 1


set origin_planets           13
set origin_aspects          373
set origin_houses           583
set origin_stars            956

# declare a global array for quality of planets
for {set i 0} {$i < 15} {incr i} {
set QualityOfPlanet($i) 0
}

# Find Quality of planets
FindQualityOfPanets


################################################################################
# Warning
################################################################################

# Name of the horoscope
if { [GetLang]=="FR" } {
 PutTxt "Interprétation de la carte du ciel de [Name] [FirstName]"
} else {
 PutTxt "Interpretation of horoscope for [Name] [FirstName]"
}

PutTxt "[BirthDateHourUT] [BirthCity] [BirthCountry]"
#

PutTxt "--------------------------------------------------------------------------------"
PutAstroTxt 1 $idfi 
PutTxt "--------------------------------------------------------------------------------"

################################################################################
# Count the number of planets (Sun to Saturn)
# above or underneath horizon.
# I don't care about Uranus, Neptune, Pluto because they are invisible.
# I may be wrong... 
################################################################################

set pa    0 ; # above
set pu    0 ; # underneath

foreach {i} {0 1 2 3 4 5 6 } {
 set diff [expr [LongOfPlanet $i $options_signs] - [LongOfPlanet $nplanet_AS  $options_signs] ]
 # must be in 0° - 360°
 set diff [ToZ360 $diff]
 if {$diff > 180} {
	incr pa 1
  } else {
	  incr pu 1
	 }
}

# more than 5 above horizon
if {$pa >= 5} {
  PutAstroTxt 2 $idfi
 
}

# more than 5 are underneath horizon
if {$pu >= 5} {
  PutAstroTxt 3 $idfi
  
}


################################################################################
# Count planets in the same side of ascendant or in opposite side
# Sun..Saturn plus Uranus, Neptun and Pluto
################################################################################

set pa    0 ; # ascendant
set po    0 ; # descendant

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set diff [expr [LongOfPlanet $i $options_signs] - [LongOfPlanet $nplanet_MH $options_signs]]
 # must be in 0° - 360°
 set diff [ToZ360 $diff]
 if {$diff > 180} {
	incr po 1
  } else {
	  incr pa 1
	 }
}

# more than 7 in ascendant side
if {$pa >= 7} {
  PutAstroTxt 4 $idfi
  
}

# more than 7 are descendant side
if {$po >= 7} {
  PutAstroTxt 5 $idfi
  
}


################################################################################
# Planets in Fire, Earth, Air and Water signs
################################################################################

set pf 0 ; # fire
set pe 0 ; # earth
set pa 0 ; # air
set pw 0 ; # water

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set nsign [SignOfPlanet $i $options_signs -rasi]
 set nsign [expr $nsign %4]  ; # remainder of division by 4
 switch $nsign {
  0 {incr pf}
  1 {incr pe}
  2 {incr pa}
  3 {incr pw}
 }
}

# most planets in fire signs
if {$pf >= 5} {
  PutAstroTxt 6 $idfi
  
}

# most planets in earth signs
if {$pe >= 5} {
  PutAstroTxt 7 $idfi
  
}

# most planets in air signs
if {$pa >= 5} {
  PutAstroTxt 8 $idfi
  
}

# most planets in water signs
if {$pw >= 5} {
  PutAstroTxt 9 $idfi
  
}


################################################################################
# Planets in Moveable, Fix, Common signs
################################################################################

set pm 0 ; # moveable
set pf 0 ; # fix
set pc 0 ; # common

foreach {i} {0 1 2 3 4 5 6 11 12 13} {
 set nsign [SignOfPlanet $i $options_signs -rasi]
 set nsign [expr $nsign %3]  ; # remainder of division by 3
 switch $nsign {
  0 {incr pm}
  1 {incr pf}
  2 {incr pc}
 }
}

# most planets in moveable signs
if {$pm >= 7} {
  PutAstroTxt 10 $idfi
  
}

# most planets in fix signs
if {$pf >= 7} {
  PutAstroTxt 11 $idfi
  
}

# most planets in common signs
if {$pc >= 7} {
  PutAstroTxt 12 $idfi
  
}

PutTxt ""

#--- free some variables ---
unset pa
unset pu
unset po
unset pf
unset pe
unset pw
unset pm
unset pc

################################################################################
# Moon is the more important planet in Fix (or Hindu) astrology, so
# let us give the interpretation for moon in sign.
################################################################################

if  { [GetLang]=="FR" } {

PutTxt "Lune"

} else {

PutTxt "Moon"

}

set ntext [expr $origin_planets + 24 + 2*[SignOfPlanet 1 $options_signs -rasi] ]

if {$QualityOfPlanet(1)< 0} {incr ntext}
PutAstroTxt $ntext $idfi

PutTxt ""

set i 1
if {$QualityOfPlanet($i)< 0} {set diff 1} else { set diff 0}
set nhouse    [HouseOfPlanet $i $options_houses -rasi $options_houses_center]

# see comment for permuteHouseNumber
set nhouse  [permuteHouseNumber $nhouse $options_houses]

set ntext   [expr $origin_houses + 24*$i + 2*($nhouse-1) + $diff]
PutAstroTxt $ntext $idfi
PutTxt ""


################################################################################
# Aspect or conjunction with the moon and the others planets
################################################################################


foreach {i} {0 2 3 4 5 6 7 8 9 10 11 12 13 14} {
 
 set qa [HQualityOfAspect 1 $i $nplanet_AS]
  
  if {$qa < 99} {
   PutAstroTxt [nAspectTxt $i 1 $qa $origin_aspects] $idfi
   PutTxt "" 
  }
 
 unset qa
 }


PutTxt "" 

################################################################################
# Ascendant and Lord of Ascendant
################################################################################

PutTxt "Ascendant" 

# Sign of Ascendant

set nplanet 7
set nsign_1 [SignOfHouse 1 $options_signs $options_houses  -rasi]
if {$QualityOfPlanet($nplanet)< 0} {set diff 1} else {set diff 0}
set ntext [expr $origin_planets + 24*$nplanet + 2*$nsign_1 +$diff]
PutAstroTxt $ntext $idfi
PutTxt ""


# Aspect on Ascendant

set nplanet 7

 for {set i 0} {$i < 15} {incr i} {
  
  if {$i != $nplanet} {
  set qa [HQualityOfAspect $nplanet $i $nplanet_AS]
  
  if {$qa < 99} {
   PutAstroTxt [nAspectTxt $i $nplanet $qa $origin_aspects] $idfi
   PutTxt ""
  }
 
 }

}

# Lord of first house (Ascendant) in sign
# if the lord is moon, nothing to do 

set nplanet [LordOfHouse 1 $options_signs $options_houses -rasi]
if {$nplanet!=1} {
 if {$QualityOfPlanet($nplanet)<0 } {set diff 1} else {set diff 0}
 set nsign   [SignOfPlanet $nplanet $options_signs -rasi]
 set ntext [expr $origin_planets + 24*$nplanet + 2*$nsign +$diff]
 PutAstroTxt $ntext $idfi
 PutTxt ""
}

# Lord of first house in house

set nplanet [LordOfHouse 1 $options_houses  $options_signs -rasi]
if {$QualityOfPlanet($nplanet)< 0} {set diff 1} else { set diff 0}
set nhouse  [HouseOfPlanet $nplanet $options_houses $options_houses_center -rasi]

# see comment for permuteHouseNumber
set nhouse  [permuteHouseNumber $nhouse $options_houses]

set ntext   [expr $origin_houses + 24*$nplanet + 2*($nhouse-1) + $diff]
PutAstroTxt $ntext $idfi
PutTxt ""

# Aspect or conjunction with Lord of ascendant

set nplanet_lord_1 [LordOfHouse 1 $options_houses  $options_signs -rasi]

 for {set i 0} {$i < 15} {incr i} {
  
  if {$i != $nplanet_lord_1} {
  set qa [HQualityOfAspect $nplanet_lord_1 $i $nplanet_AS]
  
  if {$qa < 99} {
   PutAstroTxt [nAspectTxt $i $nplanet_lord_1 $qa $origin_aspects] $idfi
   PutTxt ""
  }
 
 }

}


PutTxt ""
   

################################################################################
# Planets in sign and house. if planet is lord of house 1, nothing to do.
################################################################################

if { [GetLang]=="FR" } {

PutTxt "Planètes en Maisons et Signes" 

} else {

PutTxt "Planets in Houses and Signs" 

}


set nplanet_lord_1 [LordOfHouse 1 $options_houses  $options_signs -rasi]

for {set i 0} {$i < 15} {incr i} {
 
 # planets in signs, skip AS, Lord of As, Moon , Uranus, Neptune, Pluto, Fortune
 
 if {$i != $nplanet_AS && $i != 1 && $nplanet_lord_1 != $i && $i < 11} {
  
 set ntext [expr $origin_planets + 24*$i + 2*[SignOfPlanet $i $options_signs -rasi] ]
 if {$QualityOfPlanet($i)< 0} {incr ntext}
 PutAstroTxt $ntext $idfi
 PutTxt "" 
 
 }
 
 # planets in house
 if {$i != $nplanet_AS && $i != $nplanet_MH && $nplanet_lord_1 != $i} {
  if {$QualityOfPlanet($i)< 0} {set diff 1} else { set diff 0}
  set nhouse  [HouseOfPlanet $i $options_houses $options_houses_center -rasi]
  
  # see comment for permuteHouseNumber
  set nhouse  [permuteHouseNumber $nhouse $options_houses]
  
  set ntext   [expr $origin_houses + 24*$i + 2*($nhouse-1) + $diff]
  PutAstroTxt $ntext $idfi
  PutTxt ""
 }

}


#################################################################################
#
# Planets or As or M.H. in conjunction with fixed stars
# Orb is 1° before or after the star
#
#################################################################################
set orb 1.0

if { [GetLang]=="FR" } {
 PutTxt "Conjonctions des planètes avec les étoiles, orbe $orb ° "
} else {
 PutTxt "Conjonctions between stars and planets, orb is $orb ° "
}

PutTxt "--------------------------------------------------------------------------------"

set n_stars [GetStarsCount]

for { set p 0} {$p < 15} {incr p} {
 for {set s 0} {$s < $n_stars} { incr s} {
  set idstar [IdStarConjunctionWithPlanet $p $s $orb]
 
  if { $idstar > 0 } {
   set idstr [getPlanetUSPrefix $p]
   set idstr "$idstr$idstar"
   
   
   if { [GetLang]=="FR" } {
       PutTxt "[NameOfPlanet $p] conjonction avec [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] )"
      } else {
       PutTxt "[NameOfPlanet $p] conjunction with [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] )"
     }
     
   PutAstroTxt $idstr $idfi  -idstr -fromidstr
   PutTxt ""
      
   #set ntext [AstroIdStr2nTxt $idstr] 
 
   #if {$ntext > 0} {
   #  PutAstroTxt $ntext $idfi 
   #} else {
   # if { [GetLang]=="FR" } {
   #     PutTxt "[NameOfPlanet $p] conjonction avec [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] ) pas d'interprétation trouvée"
   #    } else {
   #     PutTxt "[NameOfPlanet $p] conjunction with [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] ) no interpretation was found"
   #   }
   # }
  
  }
 
 }
}

PutTxt "--------------------------------------------------------------------------------"

#for { set i 0} {$i < 15} {incr i} {
#  set idstar [StarConjunctionWith $i $orb]  
#  if { $idstar > 0 } {
#   set idstr [getPlanetUSPrefix $i]
#   set idstr "$idstr$idstar"
#   set ntext [AstroIdStr2nTxt $idstr] 
# 
#   if {$ntext > 0} {
#     PutAstroTxt $ntext $idfi
#   } else {
#    
#     if { [GetLang]=="FR" } {
#         PutTxt "[NameOfPlanet $i] conjonction avec [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] ) pas d'interprétation trouvée"
#        } else {
#         PutTxt "[NameOfPlanet $i] conjunction with [NameOfStar [IdStar2Num $idstar]] ( [CommentOfStar [IdStar2Num $idstar]] ) no interpretation was found"
#     }
#    }
#  PutTxt "--------------------------------------------------------------------------------"
# }
#}

